/*
 * Project name:
     EPSON_S1D13700
 * Copyright:
     (c) Mikroelektronika, 2018
 * Description:
     This is a demonstration of using EPSON_S1D13700 library functions
 * Test configuration:
     MCU:             PIC16F19176
                      http://ww1.microchip.com/downloads/en/DeviceDoc/40001923A.pdf
     Dev.Board:       EasyPIC7
                      http://www.mikroe.com/easypic/
     Oscillator:      HS, 32.0000 MHz
     Ext. Modules:    GLCD with EPSON S1D13700 controler
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
*/

// Epson S1D13700 module connections
unsigned int S1D13700_Data_Port at PORTB;
unsigned int S1D13700_Data_Port_Direction at TRISB;

sbit S1D13700_WR  at LATA0_bit;
sbit S1D13700_RD  at LATA1_bit;
sbit S1D13700_CS  at LATA2_bit;
sbit S1D13700_RES at LATA3_bit;
sbit S1D13700_A0  at LATA4_bit;

sbit S1D13700_WR_Direction  at TRISA0_bit;
sbit S1D13700_RD_Direction  at TRISA1_bit;
sbit S1D13700_CS_Direction  at TRISA2_bit;
sbit S1D13700_RES_Direction at TRISA3_bit;
sbit S1D13700_A0_Direction  at TRISA4_bit;
// End Epson S1D13700 module connections

#define S1D13700_Circle_test
#define S1D13700_Circle_Fill_test
#define S1D13700_Rectangle_Rount_Edges_Fill_test
#define S1D13700_Rectangle_Rount_Edges_test

int cnt = 0, cntMark = 5;
int x1, x2, y1, y2;

void main() {

  ANSELA = 0;
  ANSELB = 0;
  
  S1D13700_Init(320, 240);

  // S1D13700_Rectangle_Rount_Edges_Fill test.......................................
  #ifdef S1D13700_Rectangle_Rount_Edges_Fill_test

  S1D13700_Box(0, 0, 239, 127, 0);

  x1 = 63;
  x2 = 63;
  y1 = 33;
  y2 = 33;

  S1D13700_Rectangle_Round_Edges_Fill(x1-cnt, y1-cnt, x2+cnt, y2+cnt, (y2-y1+2*cnt)/2-2, 2);

  for(cnt = 0; cnt < 33; cnt+=1) {
    S1D13700_Rectangle_Round_Edges_Fill(x1-cnt, y1-cnt, x2+cnt, y2+cnt, (y2-y1+2*cnt)/2-2, 2);
  }

  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges_Fill(0, 10, 120, 58, 15, 2);
  Delay_ms(1000);
  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges_Fill(5, 15, 115, 53, 1, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges_Fill(15, 6, 100, 40, 20, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges_Fill(5, 5, 40, 40, 12, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges_Fill(5, 5, 40, 40, 12, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  S1D13700_Rectangle_Round_Edges_Fill(5, 5, 15, 15, 2, S1D13700_WHITE);
  S1D13700_Rectangle_Round_Edges_Fill(6, 6, 14, 14, 2, 2);
  Delay_ms(1000);
  #endif

  // S1D13700_Fill test.............................................................
  #ifdef S1D13700_Circle_Fill_test
  S1D13700_Box(0, 0, 239, 127, 0);
  for(cnt = cntMark; cnt < 50; cnt+=1) {
    S1D13700_Circle_Fill(64, 32, cnt, S1D13700_INVERT);
  }
  Delay_ms(1000);

  S1D13700_Circle_Fill(64, 32, 22, 2);
  Delay_ms(1000);
  S1D13700_Circle_Fill(75, 32, 20, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  S1D13700_Circle_Fill(64, 32, 5, S1D13700_WHITE);
  Delay_ms(1000);
  S1D13700_Circle_Fill(64, 32, 3, 2);
  Delay_ms(1000);
  S1D13700_Circle_Fill(60, 50, 2, 2);
  Delay_ms(1000);
  S1D13700_Circle_Fill(60, 50, 56, 2);
  Delay_ms(1000);
  S1D13700_Circle_Fill(60, 50, 40, 2);
  Delay_ms(1000);

  S1D13700_Box(0, 0, 239, 127, 0);
  S1D13700_Circle_Fill(64, 32, 0, 2);
  Delay_ms(1000);
  S1D13700_Circle_Fill(64, 32, 1, 2);
  #endif

  // S1D13700_Circle test...........................................................
  #ifdef S1D13700_Circle_test


  for(cnt = 0; cnt < 70; cnt+=1) {
    S1D13700_Circle(64, 32, cnt, 2);
  }

  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Circle(80, 32, 25, 2);
  Delay_ms(1000);
  S1D13700_Box(0, 0, 239, 127, 0);
  Delay_ms(1000);
  S1D13700_Circle(80, 32, 25, 2);
  Delay_ms(1000);
  Delay_ms(1000);
  S1D13700_Circle(64, 32, 25, 2);
  Delay_ms(1000);
  S1D13700_Circle(80, 32, 25, 2);

  S1D13700_Circle(64, 32, 25, 2);
  Delay_ms(3000);
  #endif

  // S1D13700_Rectangle_Rount_Edges test............................................
  #ifdef S1D13700_Rectangle_Rount_Edges_test
  S1D13700_Box(0, 0, 239, 127, 0);

  x1 = 63;
  x2 = 63;
  y1 = 33;
  y2 = 33;

  for(cnt = 0; cnt < 60; cnt+=1) {
    S1D13700_Rectangle_Round_Edges(x1-cnt, y1-cnt, x2+cnt, y2+cnt, (y2-y1+2*cnt)/2-2, 2);
  }
  Delay_ms(1000);

  S1D13700_Rectangle_Round_Edges(0, 10, 120, 58, 15, 2);
  Delay_ms(1000);

  S1D13700_Rectangle_Round_Edges(0, 10, 120, 58, 15, 2);
  Delay_ms(1000);

  S1D13700_Rectangle_Round_Edges(5, 15, 115, 53, 15, S1D13700_WHITE);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges(20, 6, 90, 60, 5, 2);
  Delay_ms(1000);

  S1D13700_Rectangle_Round_Edges(5, 15, 115, 53, 15, 2);
  Delay_ms(1000);
  S1D13700_Rectangle_Round_Edges(20, 6, 90, 60, 5, 2);
  Delay_ms(1000);
  #endif

}